%define kvmajor 3.10
%define kvminor 11
%define pkg_release 1
%define KRELEASE %{kvmajor}.%{kvminor}-%{release}.%{_target_cpu}

Name: kernel-xen
Version: %{kvmajor}.%{kvminor}
Release: %{pkg_release}.el%{rhel}xen
License: GPL
Group: System Environment/Kernel
URL: http://www.kernel.org
Packager: Steven Haigh <netwiz@crc.id.au>
Summary: The Linux Kernel
Vendor: The Linux Community
Provides: kernel-xen = %{version}-%{release}
Provides: kernel = %{version}-%{release}
Requires: kernel-xen-release
Requires: kernel-xen-firmware
Requires: xen
BuildRequires: git bc
BuildRoot: %_topdir/BUILDROOT
%define __spec_install_post /usr/lib/rpm/brp-compress || :
%define debug_package %{nil}

Source0: linux-%{kvmajor}.%{kvminor}.tar.xz
Source1: config-%{kvmajor}.x86_64

%description
The Linux Kernel, the operating system core itself

%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
Provides: kernel-headers = %{version}-%{release}
Provides: kernel-xen-headers = %{version}-%{release}
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
Provides: kernel-xen-firmware = %{version}-%{release}
Requires: kernel-firmware
%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%package devel
Summary: Development package for building kernel modules to match the kernel
Group: System Environment/Kernel
Provides: kernel-xen-devel = %{version}-%{release}
%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%prep
%setup -q -n linux-%{kvmajor}.%{kvminor}

make mrproper
cat $RPM_SOURCE_DIR/config-%{kvmajor}.%{_target_cpu} >> .config

%build
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}/" Makefile

%if 0%{?rhel} == 5
## EL5 based distros need CONFIG_SYSFS_DEPRECATED set, however this will break builds for
## EL6. With this in mind, we patch the .config here so both will build and work as expected.
perl -p -i -e "s/^# CONFIG_SYSFS_DEPRECATED is not set/CONFIG_SYSFS_DEPRECATED=y\nCONFIG_SYSFS_DEPRECATED_V2=y/" .config
%endif

make oldconfig
make %{?_smp_mflags} bzImage
make %{?_smp_mflags} modules

%install
rm -rf $RPM_BUILD_ROOT

## Create directory structure.
mkdir -p $RPM_BUILD_ROOT/boot
%if 0%{?rhel} == 5
touch $RPM_BUILD_ROOT/boot/initrd-%{KRELEASE}.img
%endif
%if 0%{?rhel} == 6
touch $RPM_BUILD_ROOT/boot/initramfs-%{KRELEASE}.img
%endif
mkdir -p $RPM_BUILD_ROOT/lib/modules
mkdir -p $RPM_BUILD_ROOT/lib/firmware
mkdir -p $RPM_BUILD_ROOT/usr

# Copy across all our modules.
make INSTALL_MOD_PATH=$RPM_BUILD_ROOT KBUILD_SRC= modules_install

# Create the firmware files for the kernel-xen-firmware package
make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware firmware_install

## Pull down all the firmware for kernel-xen-firmware package
echo "Cloning linux-firmware Git repo for kernel-xen-firmware package..."
git clone --depth=1 git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git

## Pick out the firmware we need for this kernel version.
## We have to cherry pick out bits here that don't conflict with kernel-firmware
## In this method, we only copy across files that don't already exist in kernel-firmware
cp linux-firmware/bnx2/bnx2-mips-06-6.2.3.fw $RPM_BUILD_ROOT/lib/firmware/bnx2/

# Install kernel headers
make ARCH=x86 INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=x86 INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h

# Manipulate the files how we want them.
cp arch/x86/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-%{KRELEASE}
cp System.map $RPM_BUILD_ROOT/boot/System.map-%{KRELEASE}
cp .config $RPM_BUILD_ROOT/boot/config-%{KRELEASE}
gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-%{KRELEASE}.gz

# mark modules as executable so rpmbuild will strip their debugging symbols
find $RPM_BUILD_ROOT/lib/modules/%{KRELEASE} -name "*.ko" -type f | xargs chmod u+x

# remove files that will be auto generated by depmod at rpm -i time
rm -f $RPM_BUILD_ROOT/lib/modules/%{KRELEASE}/modules.*
rm -f $RPM_BUILD_ROOT/lib/modules/%{KRELEASE}/build
rm -f $RPM_BUILD_ROOT/lib/modules/%{KRELEASE}/source

## Gather up all the files we need for our devel package...
mkdir -p $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
cp Module.symvers $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
cp System.map $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/

# then drop all but the needed Makefiles/Kconfig files
rm -rf $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/Documentation
rm -rf $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/scripts
rm -rf $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include

## Recopy stuff we probably do need.
cp .config $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
cp -a scripts $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
if [ -d arch/x86/scripts ]; then
	cp -a arch/x86/scripts $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/arch/x86 || :
fi
if [ -f arch/x86/*lds ]; then
	cp -a arch/x86/*lds $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/arch/x86/ || :
fi
rm -f $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/scripts/*.o
rm -f $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/scripts/*/*.o
if [ -d arch/x86/include ]; then
	cp -a --parents arch/x86/include $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/
fi
mkdir -p $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include
cd include
cp -a acpi asm-generic clocksource config crypto drm generated keys linux math-emu media memory misc net pcmcia ras rdma rxrpc scsi sound target trace uapi video xen $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include

# Make sure the Makefile and version.h have a matching timestamp so that
# external modules can be built
touch -r $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/Makefile $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include/linux/version.h
touch -r $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/.config $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include/linux/autoconf.h
# Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
cp $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/.config $RPM_BUILD_ROOT/usr/src/kernels/%{KRELEASE}/include/config/auto.conf

# Create links to kernel source....
ln -s /usr/src/kernels/%{KRELEASE} $RPM_BUILD_ROOT/lib/modules/%{KRELEASE}/build
ln -s /usr/src/kernels/%{KRELEASE} $RPM_BUILD_ROOT/lib/modules/%{KRELEASE}/source

%clean
rm -rf $RPM_BUILD_ROOT

%post
# Add kernel-xen to the list of packages that allow multiple installs
# so we don't nuke working kernels on an upgrade. That would be bad.
if ! grep -q installonlypkgs /etc/yum.conf; then
	sed -i --follow-symlinks 's/\[main]/[main]\ninstallonlypkgs=kernel kernel-xen kernel-smp kernel-bigmem kernel-enterprise kernel-debug/g' /etc/yum.conf
	echo "Added kernel-xen to 'installonlypkgs' line in /etc/yum.conf!"
fi

if [ -x /sbin/new-kernel-pkg ]
then
%if 0%{?rhel} == 5
	/sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KRELEASE} || exit $?
%endif
%if 0%{?rhel} == 6
	/sbin/new-kernel-pkg --package kernel --mkinitrd --dracut --depmod --make-default --install %{KRELEASE} || exit $?
%endif

	GRUB_CONF=$(readlink -n -e /etc/grub.conf 2>/dev/null)
	if [ -z $GRUB_CONF ]; then
		if [ -f "/boot/grub/grub.conf" ]; then
			GRUB_CONF="/boot/grub/grub.conf"
		else
			echo "No valid grub.conf found. You'll need to fix this manually!"
		fi
	else
		HYPERVISOR=`grep -m1 xen.gz $GRUB_CONF`
		if [[ -z $HYPERVISOR ]]; then
        		## We haven't found an existing hypervisor. Find where xen.gz is and add the defaults.
			echo "No existing Xen install found. Using defaults."

			## Look for /boot partition, otherwise assume relative to /
			if `grep -q "/boot" /proc/mounts`; then
				XEN_GZ="/xen.gz"
			else
				XEN_GZ="/boot/xen.gz"
			fi
			HYPERVISOR="	kernel $XEN_GZ dom0_mem=1024M cpufreq=xen dom0_max_vcpus=1 dom0_vcpus_pin"
		fi
		KERNEL=`grep -m1 vmlinuz-%{KRELEASE} $GRUB_CONF`
		INITRAMFS=`grep -m1 initramfs-%{KRELEASE} $GRUB_CONF`
		if [[ -z "$KERNEL" || -z "$INITRAMFS" ]]; then
			echo "ERROR: Something unexpected was found in /etc/grub.conf. Please edit manually."
		else   
			KERNEL_NEW=$( echo "$KERNEL" | sed 's|kernel|module|' )
			INITRAMFS_NEW=$( echo "$INITRAMFS" | sed 's|initrd|module|' )
			sed -i --follow-symlinks "s|$KERNEL|$HYPERVISOR\n$KERNEL_NEW|" $GRUB_CONF
			sed -i --follow-symlinks "s|$INITRAMFS|$INITRAMFS_NEW|" $GRUB_CONF
		fi
	fi
fi

if [ -x /sbin/weak-modules ]
then
	/sbin/weak-modules --add-kernel %{KRELEASE} || exit $?
fi

%preun
if [ -x /sbin/new-kernel-pkg ]
then
	/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KRELEASE} || exit $?
fi
if [ -x /sbin/weak-modules ]
then
	/sbin/weak-modules --remove-kernel %{KRELEASE} || exit $?
fi

%files
%defattr (-, root, root)
%dir /lib/modules
/lib/modules/%{KRELEASE}
/boot/vmlinuz-%{KRELEASE}
/boot/System.map-%{KRELEASE}
/boot/config-%{KRELEASE}
/boot/symvers-%{KRELEASE}.gz
%if 0%{?rhel} == 5
/boot/initrd-%{KRELEASE}.img
%endif
%if 0%{?rhel} == 6
/boot/initramfs-%{KRELEASE}.img
%endif

%files headers
%defattr(-,root,root)
/usr/include/*

%files firmware
%defattr(-,root,root)
/lib/firmware/*

%files devel
%defattr(-,root,root)
/usr/src/kernels/%{KRELEASE}/*
/usr/src/kernels/%{KRELEASE}/.config

%changelog
* Mon Sep 09 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.11-1
- Update to kernel 3.10.11.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.11

* Fri Aug 30 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.10-1
- Update to kernel 3.10.10.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.10

* Wed Aug 21 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.9-1
- Update to kernel 3.10.9.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.9

* Fri Aug 16 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.7-1
- Update to kernel 3.10.7.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.7

* Mon Aug 12 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.6-1
- Update to kernel 3.10.6.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.6

* Mon Aug 05 2013 Stevne Haigh <netwiz@crc.id.au> - 3.10.5-1
- Update to kernel 3.10.5.
- Fixes Xen CVE-2013-2140.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.5

* Mon Jul 29 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.4-1
- Update to kernel 3.10.4.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.4

* Fri Jul 26 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.3-1
- Update to kernel 3.10.3.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.3

* Mon Jul 22 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.2-1
- Update to kernel 3.10.2.
- Enable ZSMALLOC, ZRAM, ZCACHE - Resolves issue #14
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.2

* Sun Jul 14 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.1-1
- Update to kernel 3.10.1.
- Full changelog:
	https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.10.1

* Thu Jul 11 2013 Steven Haigh <netwiz@crc.id.au> - 3.10.0-1
- First build for kernel 3.10.0.
- Migrate kernel config to 3.10 base
- Enable bcache (http://bcache.evilpiepirate.org/)

* Fri Jul 05 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.9-1
- Update to kernel 3.9.9.

* Sat Jun 29 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.8-1
- Update to kernel 3.9.8.

* Wed Jun 26 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.7-2
- Changed default grub config file to /boot/grub/grub.conf - but also check
  /etc/grub.conf if we can't find it.

* Sat Jun 22 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.7-1
- Add scripting to auto-add xen statements to grub.conf
- Update to kernel 3.9.7
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.9.7

* Mon Jun 10 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.5-1
- Update to kernel 3.9.5
- xen-netback patches removed in favour of upstream fixes
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.9.5

* Tue May 21 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.3-1
- Update to kernel 3.9.3
- Includes fix for hotplug for physical CPU deadlock
- Includes fix for hotplug for vcpu on pvhvm hanging

* Sun May 12 2013 Steven Haigh <netwiz@crc.id.au> - 3.9.2-1
- Update to kernel 3.9.2

* Thu May 09 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.12-1
- Update to kernel 3.8.12
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.12

* Sun Apr 28 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.10-1
- Update to kernel 3.8.10
- Change CONFIG_NR_CPUS to 32
- Change CONFIG_HOTPLUG_PCI_PCIE to m to address RH BZ#908023

* Sat Apr 27 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.8-2
- Add patches to fix bug #3 where the Dom0 disables networking for
  network errors from the DomU with entries in /var/log/messages like
  Apr 25 12:09:25 hosting kernel: vif vif-4-0 vif.crc: Frag is bigger than frame.
  Apr 25 12:09:25 hosting kernel: vif vif-4-0 vif.crc: fatal error; disabling device
  Apr 25 12:09:25 hosting kernel: br0: port 5(vif.crc) entered disabled state

* Fri Apr 19 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.8-1
- Update to kernel 3.8.8
- x86, mm, paravirt: Fix vmalloc_fault oops during lazy MMU updates
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.8

* Tue Apr 16 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.7-1
- Update to kernel 3.8.7
- Maintenance release only.
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.7

* Sat Apr 06 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.6-1
- Update to kernel 3.8.6
- Xen specific fixes:
    - xen/events: avoid race with raising an event in unmask_evtchn()
    - xen-blkfront: switch from llist to list
    - xen-blkback: fix dispatch_rw_block_io() error path
    - xen/blkback: correctly respond to unknown, non-native requests
    - xen-pciback: notify hypervisor about devices intended to be assigned to guests
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.6

* Fri Mar 29 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.5-1
- Update to kernel 3.8.5
- Maintenance release only. No xen specific changes.
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.5

* Sat Mar 16 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.3-1
- Update to kernel 3.8.3
- Xen specific fixes:
    - Revert "xen/blkback: Don't trust the handle from the frontend."
    - xen/pci: We don't do multiple MSI's.
    - xen/pat: Disable PAT using pat_enabled value.
    - xenbus: fix compile failure on ARM with Xen enabled
- Config changes:
    - Enable ISCSI target mode
    - Enable support for some 10G Ethernet adapters
    - Small compatibility fixes

* Sat Mar 09 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.2-2
- Increase SKB_MAX_LEN to fix "Too many frags" on DomU vif

* Tue Mar 05 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.2-1
- Update to kernel 3.8.2
- Xen specific Fixes:
    - xen-blkback: use balloon pages for persistent grants
    - xen-blkfront: drop the use of llist_for_each_entry_safe
    - xen/blkback: Don't trust the handle from the frontend.
    - xen-blkback: do not leak mode property
- Full Changelog:
    https://www.kernel.org/pub/linux/kernel/v3.x/ChangeLog-3.8.2
- Re-enable NAT iptables target

* Sat Mar 02 2013 Steven Haigh <netwiz@crc.id.au> - 3.8.1-1
- Update to kernel 3.8.1
- Inital build with kernel 3.8.1

* Thu Feb 28 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.10-1
- Update to kernel 3.7.10
- xen-pciback: rate limit error messages from xen_pcibk_enable_msi{,x}()
- xen: close evtchn port if binding to irq fails
- xen: Send spinlock IPI to all waiters
- Full Changelog:
    http://www.kernel.org/pub/linux/kernel/v3.0/ChangeLog-3.7.10

* Mon Feb 18 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.9-1
- Update to kernel 3.7.9
- Fixes XSA-42 (CVE-2013-0228) - don't assume %ds is usable in xen_iret for 32-bit PVOPS.
- Full Changelog:
    http://www.kernel.org/pub/linux/kernel/v3.0/ChangeLog-3.7.9

* Fri Feb 15 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.8-1
- Update to kernel 3.7.8
- Xen specific fixes:
    - xen/netback: free already allocated memory on failure in xen_netbk_get_requests
    - xen/netback: don't leak pages on failure in xen_netbk_tx_check_gop.
    - xen/netback: shutdown the ring if it contains garbage.
    - netxen: fix off by one bug in netxen_release_tx_buffer()

* Mon Feb 04 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.6-1
- Update to kernel 3.7.6
- Fixes lots of netfilter, xfs and EFI/x86 bugs on newer hardware
- Full changelog:
    http://www.kernel.org/pub/linux/kernel/v3.0/ChangeLog-3.7.6
- Added Requires: kernel-firmware to fix missing firmware for some devices.

* Wed Jan 23 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.4-1
- Update to kernel 3.7.4
- Fixes XSA-40 / CVE-2013-0190
- Fix: xen/grant-table: correctly initialize grant table version 1

* Mon Jan 14 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.2-1
- Changed to XZ compression for SRPM.
- Updated to kernel 3.7.2
- Enabled CONFIG_DM_THIN_PROVISIONING

* Thu Jan 10 2013 Steven Haigh <netwiz@crc.id.au> - 3.7.1-4
- Enabled DRBD as a module.
- Added a couple of newer hardware monitoring modules

* Mon Dec 24 2012 Steven Haigh <netwiz@crc.id.au> - 3.7.1-3
- Fixed broken NAT as CONFIG option name has changed in 3.7.1
- Removed support for 32 bit Dom0 kernel. Xen 4.2 will eventually have it
  removed and kernel requires some nasty hacking to re-enable Dom0 in 32bit.
  Really, any hardware in the last few years should be x86_64 and using more
  than 4Gb of RAM - where you'd be crazy to use i686 built stuff.

* Sun Dec 23 2012 Steven Haigh <netwiz@crc.id.au> - 3.7.1-2
- Updated to upstream kernel.org 3.7.1 (3.6.x is now EOL)
- Enabled CONFIG_NETFILTER_XT_TARGET_LOG to be inline with distro kernel
- Fixed handling of kernel-xen-firmware to ONLY include extra firmare required
  to run certain devices that is not provided by kernel-firmware. This is more
  or less a whitelist that will need to be maintained by hand. Bug reports
  are welcome.
- Fixed long standing issue with versioning to make things a little more
  robust. Stops bogus versions appearing in various areas as 3.7.1.1 etc.

* Sat Dec 15 2012 Steven Haigh <netwiz@crc.id.au> - 3.6.9-3
- Resolved conflicts with distro provided firmware.

* Fri Dec 07 2012 Steven Haigh <netwiz@crc.id.au> - 3.6.9-2
- Add extra firmware from linux-firmware git archive.

* Mon Dec 04 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.9-1
- add Provides: kernel to allow removal of non-Xen kernels and satisfy deps

* Thu Nov 22 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.7
- Xen specific fixes:
  - xen/mmu: Use Xen specific TLB flush instead of the generic one.
  - xen/gntdev: don't leak memory from IOCTL_GNTDEV_MAP_GRANT_REF
- Enabled OPENVSWITCH module (See http://openvswitch.org/)
- Added kernel-xen-firmware dependency to kernel-xen to make sure we have
  firmware available for some ethernet cards if no kernel-firmware package
  is already installed.

* Tue Nov 11 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.6
- Notable fixes in this kernel version:
  ext4: fix unjournaled inode bitmap modification
  blkcg: Fix use-after-free of q->root_blkg and q->root_rl.blkg
  md/raid1: Fix assembling of arrays containing Replacements.

* Sat Nov 03 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.5
- Enabled 3ware SAS module for 9750 support.

* Thu Oct 25 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.3
  Full Changelog:
  http://www.kernel.org/pub/linux/kernel/v3.0/ChangeLog-3.6.3

* Thu Oct 16 2012 Steven Haigh <netwiz@crc.id.au>
- Update to kernel 3.6.2 (3.5 is now EOL)

* Sat Oct 13 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-3.5.4-4
- Modify to enable building on EL5

* Sat Sep 29 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-3.5.4-3
- Enable dependancies to build xtables against kernel-xen. Brings this inline with
  EL6 kernels. Patch thanks to Vasily Evseenko.

* Tue Sep 18 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-3.5.4-2
- Enable support for Hewlett-Packard Company Smart Array controllers which
  seem to be popular on HP servers.

* Mon Sep 17 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-3.5.4-1
- Update to kernel.org 3.5.4
- 3.5.4 includes the following Xen specific fixes:
	xen/pciback: Fix proper FLR steps.
	xen/p2m: Fix one-off error in checking the P2M tree directory.
	xen: Use correct masking in xen_swiotlb_alloc_coherent.
	xen/setup: Fix one-off error when adding for-balloon PFNs to the P2M.
	xen/p2m: Reuse existing P2M leafs if they are filled with 1:1 PFNs or INVALID.

* Sun Sep 02 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-3.5.3-1
- First initial build.

* Fri May 25 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.57-2
- Don't pack firmware with kernel package. That should be in kernel-xen-firmware.
  Whoops.

* Mon Mar 20 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.57-1
- Linux 2.6.32.57
  net: sock_queue_err_skb() dont mess with sk_forward_alloc
  net: fix sk_forward_alloc corruptions
  mmc: cb710 core: Add missing spin_lock_init for irq_lock of struct cb710_chip
  USB: usbserial: add new PID number (0xa951) to the ftdi driver
  usb: Skip PCI USB quirk handling for Netlogic XLP
  usb: gadget: zero: fix bug in loopback autoresume handling
  Staging: android: binder: Fix crashes when sharing a binder file between processes
  Staging: android: binder: Don't call dump_stack in binder_vma_open
  Staging: asus_oled: fix image processing
  atmel_lcdfb: fix usage of CONTRAST_CTR in suspend/resume
  eCryptfs: Infinite loop due to overflow in ecryptfs_write()
  drm/i915: Fix TV Out refresh rate.
  udf: Mark LVID buffer as uptodate before marking it dirty
  rpc client can not deal with ENOSOCK, so translate it into ENOCONN
  NFSv4: Fix open recovery
  NFSv4: Handle NFS4ERR_GRACE when recovering an expired lease.
  NFSv4: Ensure the state manager handles NFS4ERR_NO_GRACE correctly
  NFSv4: The state manager shouldn't exit on errors that were handled
  NFSv4: Fix up the callers of nfs4_state_end_reclaim_reboot

* Mon Feb 20 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.56-1
- Linux 2.6.32.56
  USB: ftdi_sio: fix initial baud rate
  USB: cp210x: do not map baud rates to B0
  USB: serial: CP210x: Added USB-ID for the Link Instruments MSO-19
  hwmon: (sht15) fix bad error code
  hwmon: (f71805f) Fix clamping of temperature limits
  USB: usbsevseg: fix max length
  usb: io_ti: Make edge_remove_sysfs_attrs the port_remove method.
  USB: cdc-wdm: updating desc->length must be protected by spin_lock
  USB: ftdi_sio: Add more identifiers
  USB: serial: ftdi additional IDs
  USB: ftdi_sio: add PID for TI XDS100v2 / BeagleBone A3
  USB: ftdi_sio: fix TIOCSSERIAL baud_base handling
  dm: do not forward ioctls from logical volumes to the underlying device
  block: fail SCSI passthrough ioctls on partition devices
  Revert "ARM: 7220/1: mmc: mmci: Fixup error handling for dma"
  crypto: sha512 - reduce stack usage to safe number
  crypto: sha512 - make it work, undo percpu message schedule
  drm: Fix authentication kernel crash
  eCryptfs: Make truncate path killable
  ecryptfs: Improve metadata read failure logging
  eCryptfs: Sanitize write counts of /dev/ecryptfs

* Fri Feb 17 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-6
- Split kernel .configs into common, i386 and x86_64 to align build options
  between both i686 and x86_64 kernel.

* Fri Feb 17 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-5
- Added i386 kernel build. No changes to x86_64 kernel.

* Sun Feb 12 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-4
- Now sign all RPMs in the repo.
- Added dependancy on kernel-xen-release to keep mirror list up to date.
  This allows new mirrors etc to be pushed without updating the kernel!
  

* Tue Feb 07 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-3
- Re-enable all but the digitv USB DVB modules.
  Sadly, digitv still fails to build.
- Minor tweak of the kernel-xen-devel package.

* Wed Feb 01 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-2 (Unreleased)
- Attempt to create kernel-xen-devel package able to build modules from.

* Wed Feb 01 2012 Steven Haigh <netwiz@crc.id.au>
- kernel-xen-2.6.32.55-1
- commit 'v2.6.32.55'
- kprobes: initialize before using a hlist
- score: fix off-by-one index into syscall table
- sym53c8xx: Fix NULL pointer dereference in slave_destroy
- ALSA: HDA: Fix internal microphone on Dell Studio 16 XPS 1645
- kernel.h: add printk_ratelimited and pr_<level>_rl
- block: add and use scsi_blk_cmd_ioctl
- USB: Fix 'bad dma' problem on WDM device disconnect
- fix cputime overflow in uptime_proc_show
- USB: cdc-wdm: fix misuse of logical operation in place of bitop
- nfsd: Fix oops when parsing a 0 length export
- svcrpc: destroy server sockets all at once
- svcrpc: fix double-free on shutdown of nfsd after changing pool mode
- V4L/DVB: v4l2-ioctl: integer overflow in video_usercopy()
- i2c: Fix error value returned by several bus drivers
- UBI: fix nameless volumes handling
- x86: Fix mmap random address range
- PNP: work around Dell 1536/1546 BIOS MMCONFIG bug that breaks USB
- ima: free duplicate measurement memory
- xen/xenbus: Reject replies with payload > XENSTORE_PAYLOAD_MAX.
- PCI: msi: Disable msi interrupts when we initialize a pci device
- PCI: Fix PCI_EXP_TYPE_RC_EC value
- UBI: fix use-after-free on error path
- HID: bump maximum global item tag report size to 96 bytes
- ALSA: hda - Return the error from get_wcaps_type() for invalid NIDs
- ALSA: ice1724 - Check for ac97 to avoid kernel oops
- ALSA: snd-usb-us122l: Delete calls to preempt_disable
- ext4: fix undefined behavior in ext4_fill_flex_info()

* Wed Jan 18 2012 Steven Haigh <netwiz@crc.id.au>
- commit 'v2.6.32.54'
--- Too many changes to list between .50 and .54!

* Sat Dec 10 2011 Steven Haigh <netwiz@crc.id.au>
- commit 'v2.6.32.50'
- Linux 2.6.32.50
- clockevents: Set noop handler in clockevents_exchange_device()
- tick-broadcast: Stop active broadcast device when replacing it
- genirq: Fix race condition when stopping the irq thread
- oprofile, x86: Fix crash when unloading module (nmi timer mode)
- x86/mpparse: Account for bus types other than ISA and PCI
- sched, x86: Avoid unnecessary overflow in sched_clock
- cifs: fix cifs stable patch cifs-fix-oplock-break-handling-try-2.patch
- SCSI: Silencing 'killing requests for dead queue'
- SCSI: scsi_lib: fix potential NULL dereference
- USB: usb-storage: unusual_devs entry for Kingston DT 101 G2
- usb: option: add SIMCom SIM5218
- usb: ftdi_sio: add PID for Propox ISPcable III
- USB: whci-hcd: fix endian conversion in qset_clear()
- Staging: comedi: fix signal handling in read and write
- staging: comedi: fix oops for USB DAQ devices.
- staging: usbip: bugfix for deadlock
- gro: reset vlan_tci on reuse
- nl80211: fix MAC address validation
- p54spi: Fix workqueue deadlock

* Fri Aug 19 2011 Steven Haigh <netwiz@crc.id.au>
! Note: USB-DVB still seems to be broken.
- commit 'v2.6.32.45':
- Linux 2.6.32.45
- powerpc: pseries: Fix kexec on machines with more than 4TB of RAM
- powerpc: Fix device tree claim code
- ALSA: snd-usb-caiaq: Fix keymap for RigKontrol3
- ALSA: timer - Fix Oops at closing slave timer
- net: Compute protocol sequence numbers and fragment IDs using MD5.
- crypto: Move md5_transform to lib/md5.c

* Sun Aug 14 2011 Steven Haigh <netwiz@crc.id.au>
- Disabled module creation for USB DVB tuners due to errors on compile. This
  will affect all DVB tuners using the dvb-usb module.
  I would assume most people who run this kernel won't use USB tuners on Dom0.
- Merged in 2.6.32.44

* Sun Aug 07 2011 Steven Haigh <netwiz@crc.id.au>
- Renamed versioning to include kernel minor version
- Fixed minor issue with some AMD CPUs

* Sun Jul 31 2011 Steven Haigh <netwiz@crc.id.au>
- Brought kernel config inline with stock EL6 kernels
- Fix: xen/blkback: don't fail empty barrier requests
- Revert "xen/blkback: When writting barriers set the sector number to zero..."
- blktap: Fix reference to freed struct request.
- Merged in 2.6.32.43
- Fixed minor bug in post-install script modifying yum.conf to recognise
  kernel-xen as a kernel package and allow multiple installs.
- Fixed bug not removing generated initramfs when removing kernel-xen package

* Thu Jul 07 2011 Steven Haigh <netwiz@crc.id.au>
- Created -headers and -firmware packages
- Add installpkgonly to /etc/yum.conf to allow multiple kernel-xen installs
  and stop yum from doing an upgrade by default.
- Added kernel-xen.repo upon installation of kernel-xen to keep things up
  to date without manually configuring the repo.

* Fri Jul 01 2011 Steven Haigh <netwiz@crc.id.au>
- updated linux to 2.6.32.41
- NEW: auto-create initramfs
- Inital public build
